@@ -22,7 +22,7 @@
 #ifndef KHC_BOOKMARKOWNER_H
 #define KHC_BOOKMARKOWNER_H
 
-#include <kbookmarkowner.h>
+#include <KBookmarkOwner>
 #include <QObject>
 
 namespace KHC {
@@ -44,7 +44,7 @@ class BookmarkOwner : public QObject, public KBookmarkOwner
     void openUrl( const QUrl& url );
 
   private:
-    View *mView;
+    View *const mView;
 };
 
 }
